_NewAbstractModel
=================

.. currentmodule:: pykeen.models

.. autoclass:: _NewAbstractModel
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~_NewAbstractModel.can_slice_h
      ~_NewAbstractModel.can_slice_r
      ~_NewAbstractModel.can_slice_t
      ~_NewAbstractModel.regularizer_default
      ~_NewAbstractModel.regularizer_default_kwargs

   .. rubric:: Methods Summary

   .. autosummary::

      ~_NewAbstractModel.collect_regularization_term
      ~_NewAbstractModel.post_parameter_update

   .. rubric:: Attributes Documentation

   .. autoattribute:: can_slice_h
   .. autoattribute:: can_slice_r
   .. autoattribute:: can_slice_t
   .. autoattribute:: regularizer_default
   .. autoattribute:: regularizer_default_kwargs

   .. rubric:: Methods Documentation

   .. automethod:: collect_regularization_term
   .. automethod:: post_parameter_update
